==> pmml-model-gwt-1.3.9-sources.jar: org/dmg/pmml/ClusteringModelQuality.java <==

package org.dmg.pmml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.jpmml.model.Property;
import org.jpmml.schema.Added;
import org.jpmml.schema.Version;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;attribute name="dataName" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="SSE" type="{http://www.dmg.org/PMML-4_3}NUMBER" />
 *       &lt;attribute name="SSB" type="{http://www.dmg.org/PMML-4_3}NUMBER" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "")
@XmlRootElement(name = "ClusteringModelQuality", namespace = "http://www.dmg.org/PMML-4_3")
@Added(Version.PMML_4_0)
public class ClusteringModelQuality
    extends PMMLObject
{

    @XmlAttribute(name = "dataName")
    private String dataName;
    @XmlAttribute(name = "SSE")
    private Double sse;
    @XmlAttribute(name = "SSB")
    private Double ssb;
    private final static long serialVersionUID = 67305479L;

    /**
     * Gets the value of the dataName property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDataName() {
        return dataName;
    }

    /**
     * Sets the value of the dataName property.
     * 
     * @param dataName
     *     allowed object is
     *     {@link String }
     *     
     */
    public ClusteringModelQuality setDataName(
        @Property("dataName")
        String dataName) {
        this.dataName = dataName;
        return this;
    }

    /**
     * Gets the value of the sse property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getSSE() {
        return sse;
    }

    /**
     * Sets the value of the sse property.
     * 
     * @param sse
     *     allowed object is
     *     {@link Double }
     *     
     */
    public ClusteringModelQuality setSSE(
        @Property("sse")
        Double sse) {
        this.sse = sse;
        return this;
    }

    /**
     * Gets the value of the ssb property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getSSB() {
        return ssb;
    }

    /**
     * Sets the value of the ssb property.
     * 
     * @param ssb
     *     allowed object is
     *     {@link Double }
     *     
     */
    public ClusteringModelQuality setSSB(
        @Property("ssb")
        Double ssb) {
        this.ssb = ssb;
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}

==> pmml-model-gwt-1.4.5-sources.jar: org/dmg/pmml/ClusteringModelQuality.java <==

package org.dmg.pmml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.jpmml.model.annotations.Added;
import org.jpmml.model.annotations.Property;

@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "")
@XmlRootElement(name = "ClusteringModelQuality", namespace = "http://www.dmg.org/PMML-4_3")
@Added((org.dmg.pmml.Version.PMML_4_0))
public class ClusteringModelQuality
    extends PMMLObject
{

    @XmlAttribute(name = "dataName")
    private String dataName;
    @XmlAttribute(name = "SSE")
    private Double sse;
    @XmlAttribute(name = "SSB")
    private Double ssb;
    private final static long serialVersionUID = 67305483L;

    public String getDataName() {
        return dataName;
    }

    public ClusteringModelQuality setDataName(
        @Property("dataName")
        String dataName) {
        this.dataName = dataName;
        return this;
    }

    public Double getSSE() {
        return sse;
    }

    public ClusteringModelQuality setSSE(
        @Property("sse")
        Double sse) {
        this.sse = sse;
        return this;
    }

    public Double getSSB() {
        return ssb;
    }

    public ClusteringModelQuality setSSB(
        @Property("ssb")
        Double ssb) {
        this.ssb = ssb;
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}
